#userprofile_avatar_container {
    border: solid 1px gray;
    margin-right: 10px;
}

#userprofile_avatar_container img {
    width: 120px;
    display: block;
}

#userprofile_avatar_container, #puserrofile_info_container {
    float: left;
}

#userprofile_title {
    font-weight: bolder;
    font-size: 20px;
    margin-bottom: 15px;
}

#userprofile_edit {
    font-size: 13px;
}

.userprofile_user_attr_title {
    font-weight: bold;
    margin-right: 5px;
}

#userprofile_end {
    clear: both;
}

#userprofile_edit_form input[type="text"],
#userprofile_edit_form input[type="password"] {
    padding: 4px;
    border: 1px solid #CCC;
    min-width: 200px;
}

#userprofile_edit_form > form > ul {
    padding: 0;
    margin: 0;
    list-style-type: none;
}

#userprofile_edit_form > form > ul > li {
    margin-top: 5px;
}

#userprofile_edit_form h3 {
    margin-bottom: 20px;
}