<html py:strip="True" py:extends="master.xhtml">

<head py:block="head" py:strip="True">
    <title>${user.display_name} Profile Edit</title>
    <link rel="stylesheet" type="text/css" media="screen" href="${profile_css}" />
</head>

<body py:block="body" py:strip="True">
    <div id="userprofile_container">
        <div id="userprofile_edit_form">
            <h3>Edit Profile</h3>
            ${form.display(user, action=h.plug_url('userprofile', '/save'))}
        </div>
    </div>
</body>
</html>
