<html py:strip="True" py:extends="master.xhtml">

<head py:block="head" py:strip="True">
  <title>${user_displayname[1]} Profile</title>
  <link rel="stylesheet" type="text/css" media="screen" href="${profile_css}" />
</head>

<body py:block="body" py:strip="True">
    <div id="userprofile_container">
        <div id="userprofile_avatar_container">
            <img id="userprofile_avatar" src="${user_avatar}" />
        </div>
        <div id="userprofile_info_container">
            <div id="userprofile_title">
                ${user_displayname[1]}
                <a href="${h.plug_url('userprofile', '/edit')}">edit</a>
            </div>
            <div id="userprofile_other_attr">
                <div py:for="attr_name, attr_value in user_data.items()"
                     id="userprofile_user_attr_${attr_name}" class="userprofile_user_attr">
                    <span class="userprofile_user_attr_title">${attr_value[0]}:</span>
                    <span class="userprofile_user_attr_value">${attr_value[1]}</span>
                </div>
            </div>
            <div py:if="user_partial">
                ${h.call_partial(user_partial, user=user)}
            </div>
        </div>
        <div id="userprofile_end"></div>
    </div>
</body>
</html>
